@@ -877,14 +877,17 @@ bool NATCompiler_ipt::addVirtualAddress::processNext()
         cluster = Cluster::cast(
             compiler->dbcopy->findInIndex(compiler->fw->getInt("parent_cluster_id")));
 
-    Address *a=NULL;
+    Address *a = NULL;
 
     if (rule->getRuleType()==NATRule::SNAT || rule->getRuleType()==NATRule::DNAT) 
     {
         if (rule->getRuleType()==NATRule::SNAT)   
-            a=compiler->getFirstTSrc(rule);
+            a = compiler->getFirstTSrc(rule);
         else
-            a=compiler->getFirstODst(rule);
+            a = compiler->getFirstODst(rule);
+
+        Interface *iface = Interface::cast(a);
+        if (iface && ! iface->isRegular()) return true;
 
         if ( ! a->isAny() &&
              ! compiler->complexMatch(a, compiler->fw) &&
@@ -894,7 +897,8 @@ bool NATCompiler_ipt::addVirtualAddress::processNext()
             {
                 compiler->warning(
                         rule, 
-                        string("Adding of virtual address for address range is not implemented (object ") +
+                        string("Adding of virtual address for address range "
+                               "is not implemented (object ") +
                         a->getName() + ")" );
             } else
                 compiler->osconfigurator->addVirtualAddressForNAT( a );
@@ -1482,30 +1486,6 @@ bool NATCompiler_ipt::splitMultipleICMP::processNext()
     return true;
 }
 
-bool NATCompiler_ipt::singleObjectNegation::processNext()
-{
-    NATRule *rule=getNext(); if (rule==NULL) return false;
-
-    RuleElement *rel = RuleElement::cast(rule->getFirstByType(re_type));
-    assert(rel);
-
-    if (rel->getNeg() && rel->size()==1)
-    {
-        FWObject *o = rel->front();
-        if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
-        Address *reladdr = Address::cast(o);
-        if ( reladdr && reladdr->countInetAddresses(true)==1 &&
-             !compiler->complexMatch(reladdr, compiler->fw)) 
-        {
-            rel->setNeg(false);
-            rel->setBool("single_object_negation", true);
-        }
-    }
-
-    tmp_queue.push_back(rule);
-    return true;
-}
-
 bool NATCompiler_ipt::doOSrcNegation::processNext()
 {
     NATRule *rule=getNext(); if (rule==NULL) return false;
@@ -2152,7 +2132,8 @@ bool NATCompiler_ipt::AssignInterface::processNext()
 
         if (iface)
         {
-            if (Cluster::isA(iface->getParentHost()))
+            FWObject *parent_host = Host::getParentHost(iface);
+            if (Cluster::isA(parent_host))
             {
 
                 if (iface->isFailoverInterface())
@@ -2339,7 +2320,13 @@ bool NATCompiler_ipt::processMultiAddressObjectsInRE::processNext()
             // we have just one object in RE and this object is MutiAddressRunTime
             if (atrt->getSubstitutionTypeName()==AddressTable::TYPENAME)
             {
-                rule->setStr("address_table_file",atrt->getSourceName());
+                string path =
+                    atrt->getSourceNameAsPath(compiler->getCachedFwOpt());
+                if (path.empty() && !atrt->getSourceName().empty()) {
+                    compiler->abort(rule, "Firewall's data directory not set for address table: " + atrt->getName());
+                    return true;
+                }
+                rule->setStr("address_table_file", path);
                 osconf->registerMultiAddressObject(atrt);
             }
             if (atrt->getSubstitutionTypeName()==DNSName::TYPENAME)
@@ -2376,7 +2363,14 @@ bool NATCompiler_ipt::processMultiAddressObjectsInRE::processNext()
             nre=RuleElement::cast( r->getFirstByType(re_type) );
             nre->clearChildren();
             nre->addRef( atrt );
-            r->setStr("address_table_file",atrt->getSourceName());
+
+            string path = atrt->getSourceNameAsPath(compiler->getCachedFwOpt());
+            if (path.empty() && !atrt->getSourceName().empty()) {
+                compiler->abort(rule, "Firewall's data directory not set for address table: " + atrt->getName());
+                return true;
+            }
+            r->setStr("address_table_file", path);
+
             osconf->registerMultiAddressObject(atrt);
             tmp_queue.push_back(r);
 
@@ -2428,12 +2422,14 @@ void NATCompiler_ipt::compile()
     add(new replaceClusterInterfaceInItfInb(
             "replace cluster interfaces with member interfaces in "
             "the inbound Interface rule element"));
+    add(new singleObjectNegationItfInb("process single object negation in inbound Itf"));
     add(new ItfInbNegation("process negation in inbound Itf"));
 
     add(new expandGroupsInItfOutb("expand groups in outbound Interface"));
     add(new replaceClusterInterfaceInItfOutb(
             "replace cluster interfaces with member interfaces in "
             "the outbound Interface rule element"));
+    add(new singleObjectNegationItfOutb("process single object negation in outbound Itf"));
     add(new ItfOutbNegation("process negation in outbound Itf"));
 
     add( new recursiveGroupsInOSrc("check for recursive groups in OSRC"));
@@ -2608,13 +2604,14 @@ void NATCompiler_ipt::compile()
     add( new simplePrintProgress() );
 
     runRuleProcessors();
-
 }
 
 
 void NATCompiler_ipt::epilog()
 {
-    if (fwopt->getBool("use_iptables_restore"))
+    if (fwopt->getBool("use_iptables_restore") &&
+        getCompiledScriptLength()>0 &&
+        ! inSingleRuleCompileMode())
     {
         output << "#" << endl;
     }
