@@ -198,9 +198,9 @@ iosaclAdvancedDialog::iosaclAdvancedDialog(QWidget *parent,FWObject *o)
 
     data.registerOption(m_dialog->ipv4before_2,    fwoptions,
                         "ipv4_6_order",
-                        QStringList() <<  "IPv4 before IPv6"
+                        QStringList() <<  tr("IPv4 before IPv6")
                         << "ipv4_first"
-                        << "IPv6 before IPv4"
+                        << tr("IPv6 before IPv4")
                         << "ipv6_first"
     );
 /* Page "Compiler Options" */
