@@ -89,8 +89,8 @@ ipcopAdvancedDialog::ipcopAdvancedDialog(QWidget *parent,FWObject *o)
 
     //QString s = fwoptions->getStr("ipv4_6_order")
     data.registerOption(m_dialog->ipv4before, fwoptions, "ipv4_6_order",
-                        QStringList() <<  "IPv4 before IPv6"
-                        <<"ipv4_first" << "IPv6 before IPv4" << "ipv6_first");
+                        QStringList() <<  tr("IPv4 before IPv6")
+                        <<"ipv4_first" << tr("IPv6 before IPv4") << "ipv6_first");
 
     data.registerOption(m_dialog->logTCPseq, fwoptions, "log_tcp_seq");
     data.registerOption(m_dialog->logTCPopt, fwoptions, "log_tcp_opt");
