@@ -81,7 +81,9 @@ iptAdvancedDialog::iptAdvancedDialog(QWidget *parent,FWObject *o)
                    obj->getStr("host_OS"),"user_can_change_install_dir").c_str());
 
     //QString s = fwoptions->getStr("ipv4_6_order")
-    data.registerOption(m_dialog->ipv4before, fwoptions, "ipv4_6_order", QStringList() <<  "IPv4 before IPv6" <<"ipv4_first" << "IPv6 before IPv4" << "ipv6_first");
+    data.registerOption(m_dialog->ipv4before, fwoptions, "ipv4_6_order",
+                        QStringList() << tr("IPv4 before IPv6")
+                        <<"ipv4_first" << tr("IPv6 before IPv4") << "ipv6_first");
 
     data.registerOption(m_dialog->logTCPseq, fwoptions, "log_tcp_seq");
     data.registerOption(m_dialog->logTCPopt, fwoptions, "log_tcp_opt");
