@@ -94,11 +94,13 @@ using namespace std;
 newFirewallDialog::newFirewallDialog(QWidget *parentw, FWObject *_p) :
     QDialog(parentw)
 {
-    parent = _p;
-    db_orig = parent->getRoot();
+
+    db_orig = _p->getRoot();
     db_copy = new FWObjectDatabase();
     db_copy->duplicate(db_orig, false);
 
+    parent = db_copy->getById(_p->getId(), true);
+
     m_dialog = new Ui::newFirewallDialog_q;
     m_dialog->setupUi(this);
 
@@ -1063,7 +1065,7 @@ bool newFirewallDialog::validateAddressAndMask(const QString &addr,
     return true;
 }
 
-void newFirewallDialog::cancelClicked()
+void newFirewallDialog::cleanup()
 {
     if (nfw)
     {
@@ -1077,7 +1079,11 @@ void newFirewallDialog::cancelClicked()
         delete tmpldb;
         tmpldb = NULL;
     }
+}
 
+void newFirewallDialog::cancelClicked()
+{
+    cleanup();
     reject();
 }
 
@@ -1277,7 +1283,6 @@ void newFirewallDialog::finishClicked()
 
     nfw = Firewall::cast(db_orig->findInIndex(nfw->getId()));
 
-
     if (tmpldb!=NULL)
     {
         delete tmpldb;
