@@ -63,6 +63,7 @@ QStringList actionsOnReject;
 QStringList routeOptions_pf_ipf;
 QStringList routeLoadOptions_pf;
 QStringList limitSuffixes;
+QStringList classifyOptions_ipfw;
 
 void init_platforms()
 {
@@ -166,6 +167,13 @@ void init_platforms()
     routeLoadOptions_pf.push_back(QObject::tr("Round Robin"));
     routeLoadOptions_pf.push_back("round_robin");
 
+    classifyOptions_ipfw.push_back(QObject::tr("None"));
+    classifyOptions_ipfw.push_back("-1");
+    classifyOptions_ipfw.push_back(QObject::tr("dummynet(4) 'pipe'"));
+    classifyOptions_ipfw.push_back("1");
+    classifyOptions_ipfw.push_back(QObject::tr("dummynet(4) 'queue'"));
+    classifyOptions_ipfw.push_back("2");
+
     limitSuffixes.push_back("");
     limitSuffixes.push_back("");
     limitSuffixes.push_back(QObject::tr("/day"));
@@ -310,8 +318,9 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
 
         if (rule!=NULL)
         {
-            PolicyRule::Action act=rule->getAction();
-            if (act==PolicyRule::Accept || act==PolicyRule::Tag || act==PolicyRule::Route)
+            PolicyRule::Action act = rule->getAction();
+
+            if (act==PolicyRule::Accept)
             {
                 // by default, these actions are not stateless
                 res = res && (!opt->getBool("stateless"));
@@ -320,6 +329,7 @@ bool isDefaultPolicyRuleOptions(FWOptions *opt)
                 // other actions are stateless by default
                 res = res && opt->getBool("stateless");
             }
+
         }
 
         // all rules are stateless for IOS ACL
@@ -531,7 +541,8 @@ void getInterfaceTypes(Interface *iface, list<QStringPair> &res)
  */
 void getSubInterfaceTypes(Interface *iface, list<QStringPair> &res)
 {
-    FWObject *p = iface->getParentHost();
+    FWObject *p = Host::getParentHost(iface);
+    //FWObject *p = iface->getParentHost();
     assert(p!=NULL);
 
     QString host_os = p->getStr("host_OS").c_str();
@@ -573,7 +584,8 @@ void setInterfaceTypes(QComboBox *iface_type,
         // Note that if resource file says this subint can not be vlan, we
         // dan't return vlan type on the list even if its name looks like
         // it could be one.
-        FWObject *p = iface->getParentHost();
+        FWObject *p = Host::getParentHost(iface);
+        //FWObject *p = iface->getParentHost();
         assert(p!=NULL);
         QString host_os = p->getStr("host_OS").c_str();
         QString obj_name = iface->getName().c_str();
@@ -671,6 +683,11 @@ const QStringList& getRouteLoadOptions_pf(const QString&)
     return routeLoadOptions_pf;
 }
 
+const QStringList& getClassifyOptions_ipfw(const QString&)
+{
+    return classifyOptions_ipfw;
+}
+
 const QStringList& getLimitSuffixes(const QString&)
 {
     return limitSuffixes;
@@ -762,9 +779,7 @@ QString getActionNameForPlatform(Firewall *fw, const std::string &action)
 bool getStatelessFlagForAction(PolicyRule *rule)
 {
     PolicyRule::Action act = rule->getAction();
-    if (act==PolicyRule::Accept ||
-        act==PolicyRule::Tag    ||
-        act==PolicyRule::Route) return false;
+    if (act==PolicyRule::Accept) return false;
     else
         return true;
 }
